bayespy.inference.vmp.nodes.gaussian.GaussianMoments.get_converter
==================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianMoments.get_converter